@@ -17,9 +17,17 @@ class Build is Panda::Builder {
                 die "This currently does not work on darwin";
             }
         }
-        my Str $destdir = "$workdir/lib/../resources/lib";
-        mkpath $destdir;
-        make("$workdir/src", "$destdir");
+        
+         my $srcdir = $workdir.IO.child('src').Str;
+         my Str $destdir = "$workdir/lib/../resources/libraries";
+         mkpath $destdir;
+         my %vars = get-vars($destdir);
+         %vars<lastloghelper> = $*VM.platform-library-name('lastloghelper'.IO).Str;
+         process-makefile($srcdir, %vars);
+         my $goback = $*CWD;
+         chdir($srcdir);
+         shell(%vars<MAKE>);
+         chdir($goback);
     }
 }
 # vim: expandtab shiftwidth=4 ft=perl6 ts=4 sts=4
